@@ -83,7 +83,7 @@ class Manifest(object):
             self.add_namespace(prefix ,ns)
     
     def to_string(self, format="xml"):
-        if not (self.altered and self._output == False):
+        if self.altered == False and isinstance(self._output, rdflib.ConjunctiveGraph):
             return self._output.serialize(format=format)
         self._output = self.get_graph()
         if isinstance(self._output, rdflib.ConjunctiveGraph):
