@@ -7,6 +7,8 @@ from rdfobject import RDFobject, NAMESPACES
 
 from rdfobject.constructs import Manifest
 
+from rdfobject.stores import ItemDoesntExistException
+
 from rdflib import ConjunctiveGraph
 
 import simplejson
@@ -65,6 +67,17 @@ class StoredEntity(Entity):
     def revert(self, create_if_nonexistent=True):
         self.load_root(create_if_nonexistent)
         self.load_manifest(create_if_nonexistent)
+        # reset mimetypes for core manifest
+        try:
+            self.manifest.del_triple("%s/%s" % (self.uri, "ROOT"), "dc:format", None)
+        except:
+            pass
+        try:
+            self.manifest.del_triple("%s/%s" % (self.uri, "MANIFEST"), "dc:format", None)
+        except:
+            pass
+        self.manifest.add_triple("%s/%s" % (self.uri, "ROOT"), "dc:format", "application/rdf+xml")
+        self.manifest.add_triple("%s/%s" % (self.uri, "MANIFEST"), "dc:format", "application/rdf+xml")
 
     @_init_obj_wrapper
     def store_root(self):
@@ -77,14 +90,26 @@ class StoredEntity(Entity):
         self.root = self.obj.getRoot()
 
     @_init_obj_wrapper
-    def put_stream(self, part_id, bytestream, commit_metadata_changes=False):
+    def put_stream(self, part_id, bytestream, mimetype=None, commit_metadata_changes=False):
         self.obj.add_part(part_id, bytestream)
         part_uri = self.uh.parse_uri("%s/%s" % (self.uri, part_id))
         self.add_triple(self.uri, "ore:aggregates", part_uri)
         self.add_triple(part_uri, "dcterms:isPartOf", self.uri)
+        if mimetype:
+            self.del_triple(part_uri, "dc:format", None)
+            self.add_triple(part_uri, "dc:format", mimetype)
+            
         if commit_metadata_changes:
             self.commit()
 
+    @_init_obj_wrapper
+    def get_stream_metadata(self, part_id):
+        part_uri = self.uh.parse_uri("%s/%s" % (self.uri, part_id))
+        try:
+            return self.manifest.get_item(part_uri)
+        except ItemDoesntExistException:
+            return
+
     @_init_obj_wrapper
     def del_stream(self, part_id, commit_metadata_changes=False):
         self.obj.del_part(part_id)
