@@ -84,19 +84,24 @@ class FileMultiEntityFactory(object):
         else:
             raise StoreNotFoundException
 
-    def add_store(self, store_name, uri_base=None, queue=None):
+    def add_store(self, store_name, uri_base=None, queue=None, refresh=False):
         store_name = self._sanitise(store_name)
-        if store_name in self.stores:
+        if store_name in self.stores and not refresh:
             return self.stores[store_name]
         else:
-            if not queue:
-                queue = self.queue
             store_path = os.path.join(self.storage_dir, store_name)
-            store = FileEntityFactory(uri_base=uri_base,
+            if self.queue  == None:
+                store = FileEntityFactory(uri_base=uri_base,
                                     storage_dir=store_path,
                                     queue=queue,
                                     prefix=self.prefix,
                                     shorty_length=self.shorty_length)
+            else:
+                store = FileEntityFactory(uri_base=uri_base,
+                                    storage_dir=store_path,
+                                    queue=self.queue,
+                                    prefix=self.prefix,
+                                    shorty_length=self.shorty_length)
             self.status[store_name] = True
             self.stores[store_name] = store
             return store
@@ -144,29 +149,31 @@ class FileMultiEntityFactory(object):
 
 class FileEntityFactory(object):
     def __init__(self, uri_base=URI_BASE, storage_dir=STORAGE_DIR,
-                        queue=None, prefix=SPECIAL_FILE_PREFIX, shorty_length=2, context={}):
+                        queue=None, prefix=SPECIAL_FILE_PREFIX, shorty_length=2, **context):
         """uri_base must end in an /, : or an #. If neither is present a / will be appended."""
         if uri_base and not(uri_base.endswith('/') or uri_base.endswith('#') or uri_base.endswith(':')):
             uri_base = "%s/" % uri_base
         factory_f = FileStorageFactory()
         self._q = queue
-        self._s = factory_f.get_store(uri_base, storage_dir, prefix, shorty_length)
+        self._s = factory_f.get_store(uri_base, storage_dir, prefix, shorty_length, queue, **context)
         self._c = context
         # The store might have a different idea on what the prefix is:
         self.uri_base = self._s.uri_base
 
+    def exists(self, id):
+        return self._s.exists(id)
 
     def get_id(self, id=None):
         uri = "%s%s" % (self.uri_base, id)
         s = StoredEntity(uri)
-        s.init(id, self._s, queue=self._q, context = self._c)
+        s.init(id, self._s, **self._c)
         return s
 
     def get(self, uri):
         if uri.startswith(self.uri_base):
             id = uri[len(self.uri_base):]
             s = StoredEntity(uri)
-            s.init(id, self._s, queue=self._q, context = self._c)
+            s.init(id, self._s, **self._c)
             return s
         else:
             raise Exception("TODO: uri not found")
@@ -174,6 +181,7 @@ class FileEntityFactory(object):
     def delete(self, uri):
         if uri.startswith(self.uri_base):
             id = uri[len(self.uri_base):]
+            
 
     def list_ids(self):
         """ EXPENSIVE - involves crawling the entire store pairtree directory"""
